====================================
Welcome to oslo.log's documentation!
====================================

The `oslo`_ log (logging) configuration library provides standardized
configuration for all openstack projects. It also provides custom
formatters, handlers and support for context specific
logging (like resource id's etc).

.. toctree::
   :maxdepth: 1

   installation
   usage
   contributing
   history

API Documentation
=================

.. toctree::
   :maxdepth: 2
   :glob:

   api/*

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _oslo: https://wiki.openstack.org/wiki/Oslo
